==> jupyter-devinstall-0.1.4.tgz: package/lib/index.js <==
#!/usr/bin/env node

"use strict";

var _prompt = require('prompt');

var prompt = _prompt;

var _chalk = require('chalk');

var chalk = _chalk;

var _request = require('request');

var request = _request;

var _path = require('path');

var path = _path;

var _expandTilde = require('expand-tilde');

var expandTilde = _expandTilde;

var _run = require('./run');

var _logging = require('./logging');

var _fs = require('./fs');

console.log(chalk.bold.cyan('Jupyter dev install tool'));
console.log(chalk.bold.cyan('Wizard for setting up a Jupyter development environment'));

var orgRepos = ['ipython/traitlets', 'ipython/ipython', 'jupyter/jupyter_core', 'jupyter/jupyter_client', 'ipython/ipykernel', 'jupyter/jupyter_console', 'jupyter/qtconsole', 'jupyter/nbformat', 'jupyter/notebook', 'ipython/ipywidgets', 'jupyter/nbconvert'];
var repos = orgRepos.map(function (x) {
    return x.split('/')[1];
});
var orgs = orgRepos.map(function (x) {
    return x.split('/')[0];
}).filter(function (x, i, self) {
    return self.indexOf(x) === i;
});

(0, _logging.section)('Config');
var config = new Promise(function (resolve) {
    prompt.start();
    prompt.get({
        properties: {
            githubName: {
                description: 'Enter your GitHub user name',
                required: true
            },
            installdir: {
                description: 'Enter the installation directory.  The installer will create ' + orgs.join(', ') + ' subfolders here.',
                required: false,
                'default': '~'
            },
            upstream: {
                description: 'Enter the name you want to use for the git remote that targets upstream',
                required: false,
                'default': 'upstream'
            },
            install: {
                description: 'Do you want the contents to be installed completely (y/n)?',
                required: false,
                pattern: /[yn]/,
                message: '`y` or `n` only',
                'default': 'y'
            }
        }
    }, function (err, result) {
        resolve(result);
    });
})['catch'](function (err) {
    console.error(chalk.bgRed('error while configuring'), err);
});

var sys_requirements = config.then(function () {
    (0, _logging.section)('Checking system requirements');
    return (0, _run.run)('git --version');
}).then(function (stdout) {
    (0, _logging.success)('git installed');
    (0, _logging.details)(stdout);
})['catch'](function (err) {
    (0, _logging.failure)('git installed');
    (0, _logging.details)('`git` not installed.  Please install git.');
    process.exit(1);
}).then(function () {
    return (0, _run.run)('python --version');
}).then(function (stdout) {
    (0, _logging.success)('python installed');
})['catch'](function (err) {
    (0, _logging.failure)('python installed');
    (0, _logging.details)('`python` not installed.  Please install python.');
    process.exit(1);
}).then(function () {
    return (0, _run.run)('python -m pip --version');
}).then(function (stdout) {
    (0, _logging.success)('pip installed');
    (0, _logging.details)(stdout);
})['catch'](function (err) {
    (0, _logging.failure)('pip installed');
    (0, _logging.details)('`pip` not installed.  Please install pip.');
    process.exit(1);
}).then(function () {
    return (0, _run.run)('node --version');
}).then(function (stdout) {
    (0, _logging.success)('node installed');
    (0, _logging.details)(stdout);
})['catch'](function (err) {
    (0, _logging.failure)('node installed');
    (0, _logging.details)('`node` not installed.  Please install node.');
    process.exit(1);
}).then(function () {
    return (0, _run.run)('npm --version');
}).then(function (stdout) {
    (0, _logging.success)('npm installed');
    (0, _logging.details)(stdout);
})['catch'](function (err) {
    (0, _logging.failure)('npm installed');
    (0, _logging.details)('`npm` not installed.  Please install npm.');
    process.exit(1);
}).then(function () {
    return (0, _run.run)('python -c \'import zmq; print "1"\'');mistune;
}).then(function (stdout) {
    (0, _logging.success)('pyzmq installed');
})['catch'](function (err) {
    (0, _logging.failure)('pyzmq installed');
    (0, _logging.details)('`pyzmq` not installed for `python`.  Please install pyzmq for python.  \nBefore installing pyzmq, you may need to install python and zmq dev packages (`python-dev` and `libzmq-dev` on debian based distros).');
    process.exit(1);
}).then(function () {
    return (0, _run.run)('python -c \'import pycurl; print "1"\'');mistune;
}).then(function (stdout) {
    (0, _logging.success)('pycurl installed');
})['catch'](function (err) {
    (0, _logging.failure)('pycurl installed');
    (0, _logging.details)('`pycurl` not installed for `python`.  Please install pycurl for python.\nBefore installing pycurl, you may need `libcurl4-openssl-dev` on debian based distros or `libcurl-devel` on slackware based distros.');
    process.exit(1);
}).then(function () {
    return config;
});

//
var gh_requirements = sys_requirements.then(function (config) {
    (0, _logging.section)('Checking github repositories');

    function findRepo(org, repo, original) {
        var orgRepo = org + '/' + repo;
        return new Promise(function (resolve, reject) {
            request('http://github.com/' + orgRepo, function (error, response, body) {
                if (!error && response.statusCode == 200) {
                    (0, _logging.success)(orgRepo + ' on GitHub');
                    resolve(body);
                } else {
                    (0, _logging.failure)(orgRepo + ' on GitHub');
                    (0, _logging.details)('Use github.com to fork ' + original + ' to ' + orgRepo);
                    reject(error || response.statusCode);
                }
            });
        });
    }

    return Promise.all(repos.map(function (x, i) {
        return findRepo(config.githubName, x, orgRepos[i]);
    }));
})['catch'](function (err) {
    process.exit(1);
}).then(function () {
    return config;
});

var downloaded = gh_requirements.then(function (config) {
    (0, _logging.section)('Downloading');

    return Promise.all(orgs.map(function (org) {

        return (0, _fs.doesntExist)(path.resolve(expandTilde(config.installdir), org)).then(function () {
            (0, _logging.success)(org + ' doesn\'t exist yet');
        })['catch'](function (err) {
            (0, _logging.failure)(org + ' doesn\'t exist yet');
            throw Error();
        });
    })).then(function () {
        return config;
    });
}).then(function (config) {

    return Promise.all(orgs.map(function (org) {
        return (0, _fs.mkdir)(path.resolve(expandTilde(config.installdir), org)).then(function () {
            (0, _logging.success)(org + ' org dir exists');
        })['catch'](function (err) {
            (0, _logging.failure)(org + ' org dir exists');
            throw Error();
        });
    })).then(function () {
        return config;
    });
}).then(function (config) {
    return Promise.all(orgRepos.map(function (orgRepo, i) {
        var url = undefined;
        // url = 'git@github.com:' + config.githubName + '/' + repos[i] + '.git';
        url = 'https://github.com/' + config.githubName + '/' + repos[i] + '.git';

        var dir = path.resolve(expandTilde(config.installdir), orgRepo);
        return (0, _run.run)('git clone ' + url + ' ' + dir).then(function () {
            (0, _logging.success)(orgRepo + ' cloned');
        })['catch'](function (err) {
            (0, _logging.failure)(orgRepo + ' cloned');
        }).then(function () {
            return (0, _run.run)('git -C ' + dir + ' remote add ' + config.upstream + ' https://github.com/' + orgRepo + '.git');
        }).then(function () {
            (0, _logging.success)(orgRepo + ' ' + config.upstream + ' remote added');
        })['catch'](function (err) {
            (0, _logging.failure)(orgRepo + ' ' + config.upstream + ' remote added');
        }).then(function () {
            return (0, _run.run)('git -C ' + dir + ' remote update');
        }).then(function () {
            (0, _logging.success)(orgRepo + ' remotes updated');
        })['catch'](function (err) {
            (0, _logging.failure)(orgRepo + ' remotes updated');
        }).then(function () {
            return (0, _run.run)('git -C ' + dir + ' checkout ' + config.upstream + '/master');
        }).then(function () {
            (0, _logging.success)(orgRepo + ' master checked out');
        })['catch'](function (err) {
            (0, _logging.failure)(orgRepo + ' master checked out');
        });
    }));
})['catch'](function (err) {
    process.exit(1);
}).then(function () {
    return config;
});

downloaded.then(function (config) {
    if (config.install === 'y') {
        var chain = Promise.resolve();

        var _loop = function (i) {
            var orgRepo = orgRepos[i];
            var shell = 'python -m pip install --user -e ' + path.resolve(expandTilde(config.installdir), orgRepo);
            chain = chain.then(function () {
                return (0, _run.run)(shell);
            }).then(function (stdout) {
                (0, _logging.success)(orgRepo + ' installed');
                (0, _logging.details)(stdout);
            })['catch'](function (err) {
                (0, _logging.failure)(orgRepo + ' installed');
                console.error(err);
                process.exit(1);
            });
        };

        for (var i = 0; i < orgRepos.length; i++) {
            _loop(i);
        }

        chain.then(function () {
            console.log(chalk.green.bold('Installation was a success!  You can launch the notebook by running `python -m IPython notebook`'));
        });
    }
});

==> jupyter-devinstall-0.1.7.tgz: package/lib/index.js <==
#!/usr/bin/env node

"use strict";

var _prompt = require('prompt');

var prompt = _prompt;

var _chalk = require('chalk');

var chalk = _chalk;

var _request = require('request');

var request = _request;

var _path = require('path');

var path = _path;

var _expandTilde = require('expand-tilde');

var expandTilde = _expandTilde;

var _run = require('./run');

var _testRun = require('./test-run');

var _logging = require('./logging');

var _fs = require('./fs');

console.log(chalk.bold.cyan('Jupyter dev install tool'));
console.log(chalk.bold.cyan('Wizard for setting up a Jupyter development environment'));

var orgRepos = ['ipython/traitlets', 'ipython/ipython', 'jupyter/jupyter_core', 'jupyter/jupyter_client', 'ipython/ipykernel', 'jupyter/jupyter_console', 'jupyter/qtconsole', 'jupyter/nbformat', 'jupyter/notebook', 'ipython/ipywidgets', 'jupyter/nbconvert'];
var repos = orgRepos.map(function (x) {
    return x.split('/')[1];
});
var orgs = orgRepos.map(function (x) {
    return x.split('/')[0];
}).filter(function (x, i, self) {
    return self.indexOf(x) === i;
});

if (process.argv.length < 4) {
    console.error('Usage: jupyter-devinstall <githubUserName> <installDir>');
    process.exit(1);
}
var githubName = process.argv[2];
var installdir = process.argv[3];

var gh_requirements = Promise.resolve().then(function () {
    (0, _logging.section)('Checking github repositories');

    function findRepo(org, repo, original) {
        var orgRepo = org + '/' + repo;
        return new Promise(function (resolve, reject) {
            request('http://github.com/' + orgRepo, function (error, response, body) {
                if (!error && response.statusCode == 200) {
                    (0, _logging.success)(orgRepo + ' on GitHub');
                    resolve(body);
                } else {
                    (0, _logging.failure)(orgRepo + ' on GitHub');
                    (0, _logging.details)('Use github.com to fork ' + original + ' to ' + orgRepo);
                    reject(error || response.statusCode);
                }
            });
        });
    }

    return Promise.all(repos.map(function (x, i) {
        return findRepo(githubName, x, orgRepos[i]);
    }));
})['catch'](function (err) {
    process.exit(1);
});

var downloaded = gh_requirements.then(function () {
    (0, _logging.section)('Checking system requirements');

    return Promise.all([(0, _testRun.testRun)('git --version'), (0, _testRun.testRun)('python --version'), (0, _testRun.testRun)('python -m pip --version', 'pip'), (0, _testRun.testRun)('node --version'), (0, _testRun.testRun)('npm --version'), (0, _testRun.testRun)('python -c "import zmq"', 'pyzmq', '`pyzmq` not installed for `python`.  Please install pyzmq for python.  \nBefore installing pyzmq, you may need to install python and zmq dev packages (`python-dev` and `libzmq-dev` on debian based distros).'), (0, _testRun.testRun)('python -c "import pycurl"', 'pycurl', '`pycurl` not installed for `python`.  Please install pycurl for python.\nBefore installing pycurl, you may need `libcurl4-openssl-dev` on debian based distros or `libcurl-devel` on slackware based distros.')]);
}).then(function () {
    (0, _logging.section)('Checking destination');

    return Promise.all(orgs.map(function (org) {

        return (0, _fs.doesntExist)(path.resolve(expandTilde(installdir), org)).then(function () {
            (0, _logging.success)(org + ' doesn\'t exist yet');
        })['catch'](function (err) {
            (0, _logging.failure)(org + ' doesn\'t exist yet');
            throw Error();
        });
    }));
}).then(function () {
    (0, _logging.section)('Config');

    return new Promise(function (resolve) {
        prompt.start();
        prompt.get({
            properties: {
                upstream: {
                    description: 'Enter the name you want to use for the git remote that targets upstream',
                    required: false,
                    'default': 'upstream'
                },
                install: {
                    description: 'Do you want the Python contents to be installed (l)ocally, (g)lobally, or (n)ot at all?',
                    required: false,
                    pattern: /[lgn]/,
                    message: '(l)ocally, (g)lobally, or (n)ot at all',
                    'default': 'l'
                }
            }
        }, function (err, result) {
            if (err) {
                console.error('\nUser exit');
                process.exit(1);
            }
            resolve(result);
        });
    })['catch'](function (err) {
        console.error(chalk.bgRed('error while configuring'), err);
    });
}).then(function (config) {
    (0, _logging.section)('Downloading');

    return Promise.all(orgs.map(function (org) {
        return (0, _fs.mkdir)(path.resolve(expandTilde(installdir), org)).then(function () {
            (0, _logging.success)(org + ' org dir exists');
        })['catch'](function (err) {
            (0, _logging.failure)(org + ' org dir exists');
            throw Error();
        });
    })).then(function () {
        return config;
    });
}).then(function (config) {

    return Promise.all(orgRepos.map(function (orgRepo, i) {
        var url = undefined;
        // url = 'git@github.com:' + githubName + '/' + repos[i] + '.git';
        url = 'https://github.com/' + githubName + '/' + repos[i] + '.git';

        var dir = path.resolve(expandTilde(installdir), orgRepo);
        return (0, _run.run)('git clone ' + url + ' ' + dir).then(function () {
            (0, _logging.success)(orgRepo + ' cloned');
        })['catch'](function (err) {
            (0, _logging.failure)(orgRepo + ' cloned');
        }).then(function () {
            return (0, _run.run)('git -C ' + dir + ' remote add ' + config.upstream + ' https://github.com/' + orgRepo + '.git');
        }).then(function () {
            (0, _logging.success)(orgRepo + ' ' + config.upstream + ' remote added');
        })['catch'](function (err) {
            (0, _logging.failure)(orgRepo + ' ' + config.upstream + ' remote added');
        }).then(function () {
            return (0, _run.run)('git -C ' + dir + ' remote update');
        }).then(function () {
            (0, _logging.success)(orgRepo + ' remotes updated');
        })['catch'](function (err) {
            (0, _logging.failure)(orgRepo + ' remotes updated');
        }).then(function () {
            return (0, _run.run)('git -C ' + dir + ' checkout ' + config.upstream + '/master');
        }).then(function () {
            (0, _logging.success)(orgRepo + ' master checked out');
        })['catch'](function (err) {
            (0, _logging.failure)(orgRepo + ' master checked out');
        });
    })).then(function () {
        return config;
    });
})['catch'](function (err) {
    console.error('Unhandled error');
    console.error(err);
    process.exit(1);
}).then(function (config) {
    if (config.install === 'l' || config.install === 'g') {
        var chain = Promise.resolve();

        var _loop = function (i) {
            var orgRepo = orgRepos[i];
            var globalFlag = config.install === 'g' ? '-g ' : '';
            var shell = 'python -m pip install --user -e ' + globalFlag + path.resolve(expandTilde(installdir), orgRepo);
            chain = chain.then(function () {
                return (0, _run.run)(shell);
            }).then(function (stdout) {
                (0, _logging.success)(orgRepo + ' installed');
                (0, _logging.details)(stdout);
            })['catch'](function (err) {
                (0, _logging.failure)(orgRepo + ' installed');
                console.error(err);
                process.exit(1);
            });
        };

        for (var i = 0; i < orgRepos.length; i++) {
            _loop(i);
        }

        chain.then(function () {
            console.log(chalk.green.bold('Installation was a success!  You can launch the notebook by running `python -m IPython notebook`'));
        });
    }
});
